@@ -1,6 +1,11 @@
 # -*- coding:utf-8 -*-
 import pandas
 
+"""
+Code接口，本地集成Code实现MyCode类。
+将数据预处理等方封装在MyCode类中，方便后续调用。
+"""
+
 
 class Code(object):
     """
