@@ -32,7 +32,7 @@ def download_repo_git(url, id,base_path, sec_path):
     return id # 返回id，用于判断后续数据使用路径
 
 
-def download_repo(id_or_url, url_type='git'):
+def download_repo(id_or_url:str, url_type='git'):
     url = ''
     id = ''
 
